@@ -5,6 +5,7 @@ from synesthesia.wsl import *
 from synesthesia.image_helper import *
 from PIL.ImageQt import ImageQt
 from synesthesia.essentia_helper import *
+import glob, os, shutil, os.path
 
 
 class Window(QWidget):
@@ -237,6 +238,10 @@ def main_func():
     app.setPalette(window.dark_mode())  # turn on dark mode
     window.show()
     app.exec()
+    print("jah test")
+    with open("infile.txt", "rb") as file:
+        print(file.read())
+
 
 if __name__ == '__main__':
     main_func()
